@@ -27,6 +27,7 @@ function neutron_agent_lbaas_install_agent_packages {
 
 function neutron_lbaas_configure_common {
     cp $NEUTRON_LBAAS_DIR/etc/neutron_lbaas.conf.sample $NEUTRON_LBAAS_CONF
+    cp $NEUTRON_LBAAS_DIR/etc/services_lbaas.conf.sample $SERVICES_LBAAS_CONF
 
     inicomment $NEUTRON_LBAAS_CONF service_providers service_provider
     iniadd $NEUTRON_LBAAS_CONF service_providers service_provider $NEUTRON_LBAAS_SERVICE_PROVIDERV2
@@ -35,14 +36,14 @@ function neutron_lbaas_configure_common {
     iniset $NEUTRON_CONF DEFAULT service_plugins $Q_SERVICE_PLUGIN_CLASSES
 
     # Ensure config is set up properly for authentication neutron-lbaas
-    iniset $NEUTRON_LBAAS_CONF service_auth auth_url $AUTH_URL
+    iniset $NEUTRON_LBAAS_CONF service_auth auth_url $OS_AUTH_URL$AUTH_ENDPOINT
     iniset $NEUTRON_LBAAS_CONF service_auth admin_tenant_name $ADMIN_TENANT_NAME
     iniset $NEUTRON_LBAAS_CONF service_auth admin_user $ADMIN_USER
     iniset $NEUTRON_LBAAS_CONF service_auth admin_password $ADMIN_PASSWORD
     iniset $NEUTRON_LBAAS_CONF service_auth auth_version $AUTH_VERSION
 
     # Ensure config is set up properly for authentication neutron
-    iniset $NEUTRON_CONF service_auth auth_url $AUTH_URL
+    iniset $NEUTRON_CONF service_auth auth_url $OS_AUTH_URL$AUTH_ENDPOINT
     iniset $NEUTRON_CONF service_auth admin_tenant_name $ADMIN_TENANT_NAME
     iniset $NEUTRON_CONF service_auth admin_user $ADMIN_USER
     iniset $NEUTRON_CONF service_auth admin_password $ADMIN_PASSWORD
@@ -89,7 +90,7 @@ function neutron_lbaas_start {
     fi
 
     if [[ "$is_run_process" == "True" ]] ; then
-        run_process $LBAAS_VERSION "python $AGENT_LBAAS_BINARY --config-file $NEUTRON_CONF --config-file $NEUTRON_LBAAS_CONF --config-file=$LBAAS_AGENT_CONF_FILENAME"
+        run_process $LBAAS_VERSION "$AGENT_LBAAS_BINARY --config-file $NEUTRON_CONF --config-file $NEUTRON_LBAAS_CONF --config-file=$LBAAS_AGENT_CONF_FILENAME"
     fi
 }
 
