@@ -261,9 +261,13 @@ class LoadBalancerPluginDbv2(base_db.CommonDbMixin,
             if provisioning_status and (model_db.provisioning_status !=
                                         provisioning_status):
                 model_db.provisioning_status = provisioning_status
+                LOG.debug("Provisioning status of %s (id=%s) updated to: %s",
+                          model_db.NAME, model_db.id, provisioning_status)
             if (operating_status and hasattr(model_db, 'operating_status') and
                     model_db.operating_status != operating_status):
                 model_db.operating_status = operating_status
+                LOG.debug("Operating status of %s (id=%s) updated to: %s",
+                          model_db.NAME, model_db.id, operating_status)
 
     def create_loadbalancer_graph(self, context, loadbalancer,
                                   allocate_vip=True):
@@ -626,7 +630,7 @@ class LoadBalancerPluginDbv2(base_db.CommonDbMixin,
 
             context.session.add(pool_db)
         context.session.refresh(pool_db.loadbalancer)
-        return data_models.Pool.from_sqlalchemy_model(pool_db)
+        return self.get_pool(context, pool_db.id)
 
     def update_pool(self, context, id, pool):
         with context.session.begin(subtransactions=True):
