@@ -13,7 +13,7 @@
 #    under the License.
 
 import abc
-from neutron.plugins.common import constants
+from neutron_lib import constants
 from oslo_log import log as logging
 import six
 
@@ -47,6 +47,46 @@ class BaseManagerMixin(object):
     def delete(self, context, obj):
         pass
 
+    def _successful_completion_lb_graph(self, context, obj):
+        listeners = obj.listeners
+        obj.listeners = []
+        for listener in listeners:
+            # need to maintain the link from the child to the load balancer
+            listener.loadbalancer = obj
+            pool = listener.default_pool
+            l7_policies = listener.l7_policies
+            if pool:
+                pool.listener = listener
+                hm = pool.healthmonitor
+                if hm:
+                    hm.pool = pool
+                    self.successful_completion(context, hm)
+                for member in pool.members:
+                    member.pool = pool
+                    self.successful_completion(context, member)
+                self.successful_completion(context, pool)
+            if l7_policies:
+                for l7policy in l7_policies:
+                    l7policy.listener = listener
+                    l7rules = l7policy.rules
+                    for l7rule in l7rules:
+                        l7rule.l7policy = l7policy
+                        self.successful_completion(context, l7rule)
+                    redirect_pool = l7policy.redirect_pool
+                    if redirect_pool:
+                        redirect_pool.listener = listener
+                        rhm = redirect_pool.healthmonitor
+                        if rhm:
+                            rhm.pool = redirect_pool
+                            self.successful_completion(context, rhm)
+                        for rmember in redirect_pool.members:
+                            rmember.pool = redirect_pool
+                            self.successful_completion(context, rmember)
+                        self.successful_completion(context, redirect_pool)
+                    self.successful_completion(context, l7policy)
+            self.successful_completion(context, listener)
+        self.successful_completion(context, obj)
+
     def successful_completion(self, context, obj, delete=False,
                               lb_create=False):
         """
@@ -54,7 +94,7 @@ class BaseManagerMixin(object):
         ACTIVE.  Should be called last in the implementor's BaseManagerMixin
         methods for successful runs.
 
-        :param context: neutron context
+        :param context: neutron_lib context
         :param obj: instance of a
                     neutron_lbaas.services.loadbalancer.data_model
         :param delete: set True if being called from a delete method.  Will
@@ -64,6 +104,9 @@ class BaseManagerMixin(object):
         """
         LOG.debug("Starting successful_completion method after a successful "
                   "driver action.")
+        if lb_create and obj.listeners:
+            self._successful_completion_lb_graph(context, obj)
+            return
         obj_sa_cls = data_models.DATA_MODEL_TO_SA_MODEL_MAP[obj.__class__]
         if delete:
             # Check if driver is responsible for vip allocation.  If the driver
@@ -112,9 +155,9 @@ class BaseManagerMixin(object):
         if isinstance(obj, data_models.HealthMonitor):
             # Health Monitor does not have an operating status
             obj_op_status = None
-        LOG.debug("Updating object of type {0} with id of {1} to "
-                  "provisioning_status = {2}, operating_status = {3}".format(
-                      obj.__class__, obj.id, constants.ACTIVE, obj_op_status))
+        LOG.debug("Updating object of type %s with id of %s to "
+                  "provisioning_status = %s, operating_status = %s",
+                  obj.__class__, obj.id, constants.ACTIVE, obj_op_status)
         self.driver.plugin.db.update_status(
             context, obj_sa_cls, obj.id,
             provisioning_status=constants.ACTIVE,
@@ -135,34 +178,34 @@ class BaseManagerMixin(object):
         be called whenever something goes wrong (raised exception) in an
         implementor's BaseManagerMixin methods.
 
-        :param context: neutron context
+        :param context: neutron_lib context
         :param obj: instance of a
                     neutron_lbaas.services.loadbalancer.data_model
         """
         LOG.debug("Starting failed_completion method after a failed driver "
                   "action.")
         if isinstance(obj, data_models.LoadBalancer):
-            LOG.debug("Updating load balancer {0} to provisioning_status = "
-                      "{1}, operating_status = {2}.".format(
-                          obj.root_loadbalancer.id, constants.ERROR,
-                          lb_const.OFFLINE))
+            LOG.debug("Updating load balancer %s to provisioning_status = "
+                      "%s, operating_status = %s.",
+                      obj.root_loadbalancer.id, constants.ERROR,
+                      lb_const.OFFLINE)
             self.driver.plugin.db.update_status(
                 context, models.LoadBalancer, obj.root_loadbalancer.id,
                 provisioning_status=constants.ERROR,
                 operating_status=lb_const.OFFLINE)
             return
         obj_sa_cls = data_models.DATA_MODEL_TO_SA_MODEL_MAP[obj.__class__]
-        LOG.debug("Updating object of type {0} with id of {1} to "
-                  "provisioning_status = {2}, operating_status = {3}".format(
-                      obj.__class__, obj.id, constants.ERROR,
-                      lb_const.OFFLINE))
+        LOG.debug("Updating object of type %s with id of %s to "
+                  "provisioning_status = %s, operating_status = %s",
+                  obj.__class__, obj.id, constants.ERROR,
+                  lb_const.OFFLINE)
         self.driver.plugin.db.update_status(
             context, obj_sa_cls, obj.id,
             provisioning_status=constants.ERROR,
             operating_status=lb_const.OFFLINE)
-        LOG.debug("Updating load balancer {0} to "
-                  "provisioning_status = {1}".format(obj.root_loadbalancer.id,
-                                                     constants.ACTIVE))
+        LOG.debug("Updating load balancer %s to "
+                  "provisioning_status = %s", obj.root_loadbalancer.id,
+                  constants.ACTIVE)
         self.driver.plugin.db.update_status(
             context, models.LoadBalancer, obj.root_loadbalancer.id,
             provisioning_status=constants.ACTIVE)
