@@ -12,8 +12,8 @@
 
 import itertools
 
-import neutron.agent.common.config
 import neutron.agent.linux.interface
+import neutron.conf.agent.common
 import neutron.conf.services.provider_configuration
 
 import neutron_lbaas.agent.agent
@@ -21,32 +21,22 @@ import neutron_lbaas.common.cert_manager
 import neutron_lbaas.common.cert_manager.local_cert_manager
 import neutron_lbaas.common.keystone
 import neutron_lbaas.drivers.common.agent_driver_base
+import neutron_lbaas.drivers.haproxy.namespace_driver
 import neutron_lbaas.drivers.octavia.driver
 import neutron_lbaas.drivers.radware.base_v2_driver
 import neutron_lbaas.extensions.loadbalancerv2
 
 
-# TODO(johndperkins): Remove when https://review.openstack.org/#/c/343045
-# merges
-try:
-    import neutron.conf.agent.common
-except ImportError:
-    pass
-
-try:
-    _INTERFACE_DRIVER_OPTS = neutron.agent.common.config.INTERFACE_DRIVER_OPTS
-except AttributeError:
-    _INTERFACE_DRIVER_OPTS = neutron.conf.agent.common.INTERFACE_DRIVER_OPTS
-
-
 def list_agent_opts():
     return [
         ('DEFAULT',
          itertools.chain(
              neutron_lbaas.agent.agent.OPTS,
              neutron.agent.linux.interface.OPTS,
-             _INTERFACE_DRIVER_OPTS)
-         )
+             neutron.conf.agent.common.INTERFACE_DRIVER_OPTS)
+         ),
+        ('haproxy',
+         neutron_lbaas.drivers.haproxy.namespace_driver.OPTS)
     ]
 
 
@@ -77,7 +67,7 @@ def list_service_opts():
          neutron_lbaas.drivers.radware.base_v2_driver.driver_debug_opts),
         ('haproxy',
          itertools.chain(
-             _INTERFACE_DRIVER_OPTS,
+             neutron.conf.agent.common.INTERFACE_DRIVER_OPTS,
              neutron_lbaas.agent.agent.OPTS,
          )),
         ('octavia',
