@@ -155,10 +155,6 @@ AGENT_TYPE_LOADBALANCERV2 = 'Loadbalancerv2 agent'
 LOADBALANCER_PLUGINV2 = 'n-lbaasv2-plugin'
 LOADBALANCER_AGENTV2 = 'n-lbaasv2_agent'
 
-# LBasS V1 Agent Constants
-LOADBALANCER_PLUGIN = 'n-lbaas-plugin'
-LOADBALANCER_AGENT = 'n-lbaas_agent'
-
 LOADBALANCER = "LOADBALANCER"
 LOADBALANCERV2 = "LOADBALANCERV2"
 
@@ -171,6 +167,7 @@ MIN_CONNECT_VALUE = -1
 LISTENER_EVENT = 'listener'
 LISTENER_STATS_EVENT = 'listener_stats'
 LOADBALANCER_EVENT = 'loadbalancer'
+LOADBALANCER_STATS_EVENT = 'loadbalancer_stats'
 MEMBER_EVENT = 'member'
 OPERATING_STATUS = 'operating_status'
 POOL_EVENT = 'pool'
