@@ -35,6 +35,7 @@ from oslo_utils import encodeutils
 
 from neutron_lbaas import agent_scheduler as agent_scheduler_v2
 import neutron_lbaas.common.cert_manager
+from neutron_lbaas.common import exceptions
 from neutron_lbaas.common.tls_utils import cert_parser
 from neutron_lbaas.db.loadbalancer import loadbalancer_dbv2 as ldbv2
 from neutron_lbaas.db.loadbalancer import models
@@ -178,6 +179,13 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
         except (lbaas_agentschedulerv2.NoEligibleLbaasAgent,
                 lbaas_agentschedulerv2.NoActiveLbaasAgent) as no_agent:
             raise no_agent
+        # Pass these exceptions through to neutron
+        except (exceptions.ConflictException,
+                exceptions.NotFoundException,
+                exceptions.NotAuthorizedException,
+                exceptions.BadRequestException,
+                exceptions.ServiceUnavailableException):
+            raise
         except Exception as e:
             LOG.exception("There was an error in the driver")
             self._handle_driver_error(context, db_entity)
@@ -1225,7 +1233,7 @@ class LoadBalancerPluginv2(loadbalancerv2.LoadBalancerPluginBaseV2,
             if healthmonitor:
                 if not healthmonitor.admin_state_up:
                     dhm = self._disable_entity_and_children(healthmonitor)
-                    pool_status["healthmonitor"] = dhm
+                    hm_status = dhm
                 else:
                     hm_status = self._default_status(healthmonitor,
                                 exclude=[OS], type=healthmonitor.type)
