@@ -18,9 +18,10 @@ import time
 from oslo_log import log as logging
 from tempest.api.network import base
 from tempest import config
+from tempest.lib.common.utils import test_utils
 from tempest.lib import exceptions
 
-from neutron_lbaas._i18n import _, _LI
+from neutron_lbaas._i18n import _
 from neutron_lbaas.tests.tempest.v2.clients import health_monitors_client
 from neutron_lbaas.tests.tempest.v2.clients import listeners_client
 from neutron_lbaas.tests.tempest.v2.clients import load_balancers_client
@@ -64,6 +65,10 @@ class BaseTestCase(base.BaseNetworkTest):
     def resource_setup(cls):
         super(BaseTestCase, cls).resource_setup()
 
+        cls.listener_protocol = CONF.lbaas.default_listener_protocol
+        cls.pool_protocol = CONF.lbaas.default_pool_protocol
+        cls.hm_protocol = CONF.lbaas.default_health_monitor_protocol
+
         mgr = cls.get_client_manager()
         auth_provider = mgr.auth_provider
         client_args = _setup_client_args(auth_provider)
@@ -88,25 +93,36 @@ class BaseTestCase(base.BaseNetworkTest):
                 continue
             for listener in lb.get('listeners'):
                 for pool in listener.get('pools'):
+                    # delete pool's health-monitor
                     hm = pool.get('healthmonitor')
                     if hm:
-                        cls._try_delete_resource(
+                        test_utils.call_and_ignore_notfound_exc(
                             cls.health_monitors_client.delete_health_monitor,
                             pool.get('healthmonitor').get('id'))
                         cls._wait_for_load_balancer_status(lb_id)
-                    cls._try_delete_resource(cls.pools_client.delete_pool,
-                                             pool.get('id'))
+                    test_utils.call_and_ignore_notfound_exc(
+                        cls.pools_client.delete_pool,
+                        pool.get('id'))
                     cls._wait_for_load_balancer_status(lb_id)
-                    health_monitor = pool.get('healthmonitor')
-                    if health_monitor:
-                        cls._try_delete_resource(
-                            cls.health_monitors_client.delete_health_monitor,
-                            health_monitor.get('id'))
+                    # delete pool's members
+                    members = pool.get('members', [])
+                    for member in members:
+                        test_utils.call_and_ignore_notfound_exc(
+                            cls.members_client.delete_member,
+                            pool.get('id'), member.get('id'))
+                        cls._wait_for_load_balancer_status(lb_id)
+                    # delete pool
+                    test_utils.call_and_ignore_notfound_exc(
+                        cls.pools_client.delete_pool, pool.get('id'))
                     cls._wait_for_load_balancer_status(lb_id)
-                cls._try_delete_resource(cls.listeners_client.delete_listener,
-                                         listener.get('id'))
+                # delete listener
+                test_utils.call_and_ignore_notfound_exc(
+                    cls.listeners_client.delete_listener,
+                    listener.get('id'))
                 cls._wait_for_load_balancer_status(lb_id)
-            cls._try_delete_resource(cls._delete_load_balancer, lb_id)
+            # delete load-balancer
+            test_utils.call_and_ignore_notfound_exc(
+                cls._delete_load_balancer, lb_id)
 
         super(BaseTestCase, cls).resource_cleanup()
 
@@ -116,12 +132,12 @@ class BaseTestCase(base.BaseNetworkTest):
         super(BaseTestCase, cls).setUpClass()
 
     def setUp(cls):
-        cls.LOG.info(_LI('Starting: {0}').format(cls._testMethodName))
+        cls.LOG.info('Starting: {0}'.format(cls._testMethodName))
         super(BaseTestCase, cls).setUp()
 
     def tearDown(cls):
         super(BaseTestCase, cls).tearDown()
-        cls.LOG.info(_LI('Finished: {0}\n').format(cls._testMethodName))
+        cls.LOG.info('Finished: {0}\n'.format(cls._testMethodName))
 
     @classmethod
     def _create_load_balancer(cls, wait=True, **lb_kwargs):
@@ -182,13 +198,13 @@ class BaseTestCase(base.BaseNetworkTest):
                         lb.get('operating_status') == operating_status):
                     break
                 time.sleep(interval_time)
-            except exceptions.NotFound as e:
+            except exceptions.NotFound:
                 # if wait is for delete operation do break
                 if delete:
                     break
                 else:
                     # raise original exception
-                    raise e
+                    raise
         else:
             if delete:
                 raise exceptions.TimeoutException(
