@@ -15,6 +15,7 @@
 #    under the License.
 
 from tempest.lib.common.utils import data_utils
+from tempest.lib import decorators
 from tempest.lib import exceptions as ex
 from tempest import test
 
@@ -42,11 +43,10 @@ class ListenersTestJSON(base.BaseAdminTestCase):
                                 'vip_subnet_id': cls.subnet['id']}
         cls.load_balancer = cls._create_active_load_balancer(
             **cls.create_lb_kwargs)
-        cls.protocol = 'HTTP'
         cls.port = 80
         cls.load_balancer_id = cls.load_balancer['id']
         cls.create_listener_kwargs = {'loadbalancer_id': cls.load_balancer_id,
-                                      'protocol': cls.protocol,
+                                      'protocol': cls.listener_protocol,
                                       'protocol_port': cls.port}
         cls.listener = cls._create_listener(
             **cls.create_listener_kwargs)
@@ -56,7 +56,7 @@ class ListenersTestJSON(base.BaseAdminTestCase):
     def resource_cleanup(cls):
         super(ListenersTestJSON, cls).resource_cleanup()
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_empty_tenant_id(self):
         """Test create listener with an empty tenant id should fail"""
         create_new_listener_kwargs = self.create_listener_kwargs
@@ -85,7 +85,7 @@ class ListenersTestJSON(base.BaseAdminTestCase):
             new_listener_id)
         self.assertEqual(new_listener, listener)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_create_listener_missing_tenant_id(self):
         """Test create listener with an missing tenant id.
 
