@@ -14,6 +14,7 @@
 #    under the License.
 
 from tempest.lib.common.utils import data_utils
+from tempest.lib import decorators
 from tempest.lib import exceptions as ex
 from tempest import test
 
@@ -46,16 +47,15 @@ class ListenersTestJSON(base.BaseTestCase):
                                 'vip_subnet_id': cls.subnet['id']}
         cls.load_balancer = cls._create_active_load_balancer(
             **cls.create_lb_kwargs)
-        cls.protocol = 'HTTP'
         cls.port = 80
         cls.load_balancer_id = cls.load_balancer['id']
         cls.create_listener_kwargs = {'loadbalancer_id': cls.load_balancer_id,
-                                      'protocol': cls.protocol,
+                                      'protocol': cls.listener_protocol,
                                       'protocol_port': cls.port}
         cls.listener = cls._create_listener(**cls.create_listener_kwargs)
         cls.listener_id = cls.listener['id']
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_get_listener(self):
         """Test get listener"""
         listener = self.listeners_client.get_listener(
@@ -72,7 +72,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_list_listeners_two(self):
         """Test get listeners with two listeners"""
         create_new_listener_kwargs = self.create_listener_kwargs
@@ -90,7 +90,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self.assertIn(new_listener, listeners)
         self.assertNotEqual(self.listener, new_listener)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_create_listener(self):
         """Test create listener"""
         create_new_listener_kwargs = self.create_listener_kwargs
@@ -107,17 +107,17 @@ class ListenersTestJSON(base.BaseTestCase):
         self.assertEqual(new_listener, listener)
         self.assertNotEqual(self.listener, new_listener)
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_missing_field_loadbalancer(self):
         """Test create listener with a missing required field loadbalancer"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           protocol_port=self.port,
-                          protocol=self.protocol)
+                          protocol=self.listener_protocol)
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_missing_field_protocol(self):
         """Test create listener with a missing required field protocol"""
         self.assertRaises(ex.BadRequest,
@@ -127,13 +127,13 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_missing_field_protocol_port(self):
         """Test create listener with a missing required field protocol_port"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
-                          protocol=self.protocol)
+                          protocol=self.listener_protocol)
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
@@ -153,18 +153,18 @@ class ListenersTestJSON(base.BaseTestCase):
         self.assertEqual(new_listener, listener)
         self.assertTrue(new_listener['admin_state_up'])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_invalid_load_balancer_id(self):
         """Test create listener with an invalid load_balancer_id"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id="234*",
                           protocol_port=self.port,
-                          protocol=self.protocol)
+                          protocol=self.listener_protocol)
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_invalid_protocol(self):
         """Test create listener with an invalid protocol"""
         self.assertRaises(ex.BadRequest,
@@ -175,65 +175,65 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_invalid_protocol_port(self):
         """Test create listener with an invalid protocol_port"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port="9999999",
-                          protocol=self.protocol)
+                          protocol=self.listener_protocol)
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_invalid_admin_state_up(self):
         """Test update listener with an invalid admin_state_up"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           protocol_port=self.port,
-                          protocol=self.protocol,
+                          protocol=self.listener_protocol,
                           admin_state_up="abc123")
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_invalid_tenant_id(self):
         """Test create listener with an invalid tenant id"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
-                          protocol=self.protocol,
+                          protocol=self.listener_protocol,
                           tenant_id="&^%123")
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_invalid_name(self):
         """Test create listener with an invalid name"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
-                          protocol=self.protocol,
+                          protocol=self.listener_protocol,
                           name='a' * 256)
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_invalid_description(self):
         """Test create listener with an invalid description"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
-                          protocol=self.protocol,
+                          protocol=self.listener_protocol,
                           description='a' * 256)
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_invalid_connection_limit(self):
         """Test create listener with an invalid value for connection
         _limit field
@@ -242,23 +242,23 @@ class ListenersTestJSON(base.BaseTestCase):
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
-                          protocol=self.protocol,
+                          protocol=self.listener_protocol,
                           connection_limit="&^%123")
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_empty_load_balancer_id(self):
         """Test create listener with an empty load_balancer_id"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id="",
                           protocol_port=self.port,
-                          protocol=self.protocol)
+                          protocol=self.listener_protocol)
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_empty_protocol(self):
         """Test create listener with an empty protocol"""
         self.assertRaises(ex.BadRequest,
@@ -269,36 +269,36 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_empty_protocol_port(self):
         """Test create listener with an empty protocol_port"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port="",
-                          protocol=self.protocol)
+                          protocol=self.listener_protocol)
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_empty_admin_state_up(self):
         """Test update listener with an empty  admin_state_up"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           protocol_port=self.port,
-                          protocol=self.protocol,
+                          protocol=self.listener_protocol,
                           admin_state_up="")
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_empty_tenant_id(self):
         """Test create listener with an empty tenant id"""
         self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
-                          protocol=self.protocol,
+                          protocol=self.listener_protocol,
                           tenant_id="")
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
@@ -335,7 +335,7 @@ class ListenersTestJSON(base.BaseTestCase):
             new_listener_id)
         self.assertEqual(new_listener, listener)
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_empty_connection_limit(self):
         """Test create listener with an empty connection
         _limit field
@@ -344,12 +344,12 @@ class ListenersTestJSON(base.BaseTestCase):
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
-                          protocol=self.protocol,
+                          protocol=self.listener_protocol,
                           connection_limit="")
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_listener_incorrect_attribute(self):
         """Test create a listener with an extra, incorrect field"""
         self.assertRaises(ex.BadRequest,
@@ -359,7 +359,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_update_listener(self):
         """Test update listener"""
         self._update_listener(self.listener_id,
@@ -370,7 +370,7 @@ class ListenersTestJSON(base.BaseTestCase):
             self.listener_id)
         self.assertEqual(listener.get('name'), 'new_name')
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_invalid_tenant_id(self):
         """Test update listener with an invalid tenant id"""
         self.assertRaises(ex.BadRequest,
@@ -380,7 +380,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_invalid_admin_state_up(self):
         """Test update a listener with an invalid admin_state_up"""
         self.assertRaises(ex.BadRequest,
@@ -390,7 +390,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_invalid_name(self):
         """Test update a listener with an invalid name"""
         self.assertRaises(ex.BadRequest,
@@ -400,7 +400,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_invalid_description(self):
         """Test update a listener with an invalid description"""
         self.assertRaises(ex.BadRequest,
@@ -410,7 +410,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_invalid_connection_limit(self):
         """Test update a listener with an invalid connection_limit"""
         self.assertRaises(ex.BadRequest,
@@ -420,7 +420,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_incorrect_attribute(self):
         """Test update a listener with an extra, incorrect field"""
         self.assertRaises(ex.BadRequest,
@@ -487,7 +487,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self.assertEqual(listener.get('connection_limit'),
                          old_connection_limit)
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_empty_tenant_id(self):
         """Test update listener with an empty tenant id"""
         self.assertRaises(ex.BadRequest,
@@ -497,7 +497,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_empty_admin_state_up(self):
         """Test update a listener with an empty admin_state_up"""
         self.assertRaises(ex.BadRequest,
@@ -527,7 +527,7 @@ class ListenersTestJSON(base.BaseTestCase):
             self.listener_id)
         self.assertEqual(listener.get('description'), "")
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_update_listener_empty_connection_limit(self):
         """Test update a listener with an empty connection_limit"""
         self.assertRaises(ex.BadRequest,
@@ -537,7 +537,7 @@ class ListenersTestJSON(base.BaseTestCase):
         self._check_status_tree(load_balancer_id=self.load_balancer_id,
                                 listener_ids=[self.listener_id])
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_delete_listener(self):
         """Test delete listener"""
         create_new_listener_kwargs = self.create_listener_kwargs
