@@ -59,13 +59,14 @@ class TestPools(base.BaseAdminTestCase):
                                  listener_id=None, cleanup=True, **kwargs):
         self.increment_protocol_port()
         if not protocol:
-            protocol = 'HTTP'
+            protocol = self.pool_protocol
         if not lb_algorithm:
             lb_algorithm = 'ROUND_ROBIN'
         if not listener_id:
             listener = self._create_listener(
                 loadbalancer_id=self.load_balancer.get('id'),
-                protocol='HTTP', protocol_port=PROTOCOL_PORT, **kwargs)
+                protocol=self.listener_protocol,
+                protocol_port=PROTOCOL_PORT, **kwargs)
             listener_id = listener.get('id')
         response = self._create_pool(protocol=protocol,
                                      lb_algorithm=lb_algorithm,
@@ -75,11 +76,11 @@ class TestPools(base.BaseAdminTestCase):
             self.addCleanup(self._delete_pool, response['id'])
         return response
 
-    @test.attr(type='negative')
+    @decorators.attr(type='negative')
     def test_create_pool_using_empty_tenant_field(self):
         """Test create pool with empty tenant field should fail"""
         self.assertRaises(ex.BadRequest, self._create_pool,
-                          protocol='HTTP',
+                          protocol=self.pool_protocol,
                           tenant_id="",
                           lb_algorithm='ROUND_ROBIN')
 
@@ -90,9 +91,7 @@ class TestPools(base.BaseAdminTestCase):
         tenant_id does not match when creating pool vs.
         pool (admin client)
         """
-        new_pool = self._prepare_and_create_pool(
-            protocol='HTTP',
-            lb_algorithm='ROUND_ROBIN')
+        new_pool = self._prepare_and_create_pool()
         pool = self.pools_client.get_pool(new_pool.get('id'))
         pool_tenant = pool['tenant_id']
         self.assertNotEqual(pool_tenant, self.subnet['tenant_id'])
@@ -103,15 +102,13 @@ class TestPools(base.BaseAdminTestCase):
         Test create pool with a missing tenant id field. Verify
         tenant_id matches when creating pool vs. pool (admin client)
         """
-        new_pool = self._prepare_and_create_pool(
-            protocol='HTTP',
-            lb_algorithm='ROUND_ROBIN')
+        new_pool = self._prepare_and_create_pool()
         pool = self.pools_client.get_pool(new_pool.get('id'))
         pool_tenant = pool['tenant_id']
         self.assertEqual(pool_tenant, pool.get('tenant_id'))
 
     @decorators.skip_because(bug="1468457")
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_create_pool_for_another_tenant(self):
         """Test create pool for other tenant field"""
         tenant = 'deffb4d7c0584e89a8ec99551565713c'
@@ -121,7 +118,7 @@ class TestPools(base.BaseAdminTestCase):
         pool_tenant = pool.get('tenant_id')
         self.assertEqual(pool_tenant, tenant)
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_update_pool_sesssion_persistence_app_cookie(self):
         """Test update admin pool's session persistence"""
         new_pool = self._prepare_and_create_pool()
@@ -148,7 +145,7 @@ class TestPools(base.BaseAdminTestCase):
                                "cookie_name": None}
         self.assertEqual(session_persistence, pool.get('session_persistence'))
 
-    @test.attr(type='smoke')
+    @decorators.attr(type='smoke')
     def test_delete_pool(self):
         """Test delete admin pool"""
         new_pool = self._prepare_and_create_pool(cleanup=False)
