@@ -15,11 +15,11 @@
 import contextlib
 import copy
 import mock
+from neutron_lib import context
+from neutron_lib.plugins import constants
 from neutron_lib.plugins import directory
 import re
 
-from neutron import context
-from neutron.plugins.common import constants
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 from six.moves import queue as Queue
@@ -128,6 +128,7 @@ WF_CREATE_PARAMS = {'parameters':
 
 WF_APPLY_PARAMS = {
     'parameters': {'listeners': [], 'pools': [], 'admin_state_up': True,
+    'configure_allowed_address_pairs': False,
     'pip_address': u'10.0.0.2', 'vip_address': u'10.0.0.2'}}
 
 LISTENER = {
