@@ -16,13 +16,14 @@
 import copy
 
 import mock
-from neutron.api.v2 import attributes as attr
-from neutron.plugins.common import constants
 from neutron.tests.unit.api.v2 import test_base
+from neutron_lib import constants as n_constants
+from neutron_lib.plugins import constants
 from oslo_utils import uuidutils
 from webob import exc
 
-from neutron_lbaas.extensions import loadbalancer
+from neutron_lbaas.extensions import healthmonitor_max_retries_down as hm_down
+from neutron_lbaas.extensions import lb_network_vip
 from neutron_lbaas.extensions import loadbalancerv2
 from neutron_lbaas.extensions import sharedpools
 from neutron_lbaas.tests import base
@@ -32,469 +33,18 @@ _uuid = uuidutils.generate_uuid
 _get_path = test_base._get_path
 
 
-class LoadBalancerExtensionTestCase(base.ExtensionTestCase):
+class TestLoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
     fmt = 'json'
 
     def setUp(self):
-        super(LoadBalancerExtensionTestCase, self).setUp()
-        self._setUpExtension(
-            'neutron_lbaas.extensions.loadbalancer.LoadBalancerPluginBase',
-            constants.LOADBALANCER, loadbalancer.RESOURCE_ATTRIBUTE_MAP,
-            loadbalancer.Loadbalancer, 'lb', use_quota=True)
-
-    def test_vip_create(self):
-        vip_id = _uuid()
-        data = {'vip': {'name': 'vip1',
-                        'description': 'descr_vip1',
-                        'subnet_id': _uuid(),
-                        'address': '127.0.0.1',
-                        'protocol_port': 80,
-                        'protocol': 'HTTP',
-                        'pool_id': _uuid(),
-                        'session_persistence': {'type': 'HTTP_COOKIE'},
-                        'connection_limit': 100,
-                        'admin_state_up': True,
-                        'tenant_id': _uuid()}}
-        return_value = copy.copy(data['vip'])
-        return_value.update({'status': "ACTIVE", 'id': vip_id})
-
-        instance = self.plugin.return_value
-        instance.create_vip.return_value = return_value
-        res = self.api.post(_get_path('lb/vips', fmt=self.fmt),
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt)
-        instance.create_vip.assert_called_with(mock.ANY,
-                                               vip=data)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('vip', res)
-        self.assertEqual(return_value, res['vip'])
-
-    def test_vip_create_with_connection_limit_smaller_than_min_value(self):
-        data = {'vip': {'name': 'vip1',
-                        'description': 'descr_vip1',
-                        'subnet_id': _uuid(),
-                        'address': '127.0.0.1',
-                        'protocol_port': 80,
-                        'protocol': 'HTTP',
-                        'pool_id': _uuid(),
-                        'session_persistence': {'type': 'HTTP_COOKIE'},
-                        'connection_limit': -4,
-                        'admin_state_up': True,
-                        'tenant_id': _uuid()}}
-        res = self.api.post(_get_path('lb/vips', fmt=self.fmt),
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt,
-                            expect_errors=True)
-        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
-
-    def test_vip_list(self):
-        vip_id = _uuid()
-        return_value = [{'name': 'vip1',
-                         'admin_state_up': True,
-                         'tenant_id': _uuid(),
-                         'id': vip_id}]
-
-        instance = self.plugin.return_value
-        instance.get_vips.return_value = return_value
-
-        res = self.api.get(_get_path('lb/vips', fmt=self.fmt))
-
-        instance.get_vips.assert_called_with(mock.ANY, fields=mock.ANY,
-                                             filters=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-
-    def test_vip_update(self):
-        vip_id = _uuid()
-        update_data = {'vip': {'admin_state_up': False}}
-        return_value = {'name': 'vip1',
-                        'admin_state_up': False,
-                        'tenant_id': _uuid(),
-                        'status': "ACTIVE",
-                        'id': vip_id}
-
-        instance = self.plugin.return_value
-        instance.update_vip.return_value = return_value
-
-        res = self.api.put(_get_path('lb/vips', id=vip_id, fmt=self.fmt),
-                           self.serialize(update_data))
-
-        instance.update_vip.assert_called_with(mock.ANY, vip_id,
-                                               vip=update_data)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('vip', res)
-        self.assertEqual(return_value, res['vip'])
-
-    def test_vip_update_with_connection_limit_smaller_than_min_value(self):
-        vip_id = _uuid()
-        data = {'vip': {'connection_limit': -4}}
-        res = self.api.put(_get_path('lb/vips', id=vip_id, fmt=self.fmt),
-                           self.serialize(data),
-                           content_type='application/%s' % self.fmt,
-                           expect_errors=True)
-        self.assertEqual(exc.HTTPBadRequest.code, res.status_int)
-
-    def test_vip_get(self):
-        vip_id = _uuid()
-        return_value = {'name': 'vip1',
-                        'admin_state_up': False,
-                        'tenant_id': _uuid(),
-                        'status': "ACTIVE",
-                        'id': vip_id}
-
-        instance = self.plugin.return_value
-        instance.get_vip.return_value = return_value
-
-        res = self.api.get(_get_path('lb/vips', id=vip_id, fmt=self.fmt))
-
-        instance.get_vip.assert_called_with(mock.ANY, vip_id,
-                                            fields=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('vip', res)
-        self.assertEqual(return_value, res['vip'])
-
-    def test_vip_delete(self):
-        self._test_entity_delete('vip')
-
-    def test_pool_create(self):
-        pool_id = _uuid()
-        hm_id = _uuid()
-        data = {'pool': {'name': 'pool1',
-                         'description': 'descr_pool1',
-                         'subnet_id': _uuid(),
-                         'protocol': 'HTTP',
-                         'lb_method': 'ROUND_ROBIN',
-                         'health_monitors': [hm_id],
-                         'admin_state_up': True,
-                         'tenant_id': _uuid()}}
-        return_value = copy.copy(data['pool'])
-        return_value['provider'] = 'lbaas'
-        return_value.update({'status': "ACTIVE", 'id': pool_id})
-
-        instance = self.plugin.return_value
-        instance.create_pool.return_value = return_value
-        res = self.api.post(_get_path('lb/pools', fmt=self.fmt),
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt)
-        data['pool']['provider'] = attr.ATTR_NOT_SPECIFIED
-        instance.create_pool.assert_called_with(mock.ANY,
-                                                pool=data)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('pool', res)
-        self.assertEqual(return_value, res['pool'])
-
-    def test_pool_list(self):
-        pool_id = _uuid()
-        return_value = [{'name': 'pool1',
-                         'admin_state_up': True,
-                         'tenant_id': _uuid(),
-                         'id': pool_id}]
-
-        instance = self.plugin.return_value
-        instance.get_pools.return_value = return_value
-
-        res = self.api.get(_get_path('lb/pools', fmt=self.fmt))
-
-        instance.get_pools.assert_called_with(mock.ANY, fields=mock.ANY,
-                                              filters=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-
-    def test_pool_update(self):
-        pool_id = _uuid()
-        update_data = {'pool': {'admin_state_up': False}}
-        return_value = {'name': 'pool1',
-                        'admin_state_up': False,
-                        'tenant_id': _uuid(),
-                        'status': "ACTIVE",
-                        'id': pool_id}
-
-        instance = self.plugin.return_value
-        instance.update_pool.return_value = return_value
-
-        res = self.api.put(_get_path('lb/pools', id=pool_id, fmt=self.fmt),
-                           self.serialize(update_data))
-
-        instance.update_pool.assert_called_with(mock.ANY, pool_id,
-                                                pool=update_data)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('pool', res)
-        self.assertEqual(return_value, res['pool'])
-
-    def test_pool_get(self):
-        pool_id = _uuid()
-        return_value = {'name': 'pool1',
-                        'admin_state_up': False,
-                        'tenant_id': _uuid(),
-                        'status': "ACTIVE",
-                        'id': pool_id}
-
-        instance = self.plugin.return_value
-        instance.get_pool.return_value = return_value
-
-        res = self.api.get(_get_path('lb/pools', id=pool_id, fmt=self.fmt))
-
-        instance.get_pool.assert_called_with(mock.ANY, pool_id,
-                                             fields=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('pool', res)
-        self.assertEqual(return_value, res['pool'])
-
-    def test_pool_delete(self):
-        self._test_entity_delete('pool')
-
-    def test_pool_stats(self):
-        pool_id = _uuid()
-
-        stats = {'stats': 'dummy'}
-        instance = self.plugin.return_value
-        instance.stats.return_value = stats
-
-        path = _get_path('lb/pools', id=pool_id,
-                         action="stats", fmt=self.fmt)
-        res = self.api.get(path)
-
-        instance.stats.assert_called_with(mock.ANY, pool_id)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('stats', res)
-        self.assertEqual(stats['stats'], res['stats'])
-
-    def test_member_create(self):
-        member_id = _uuid()
-        data = {'member': {'pool_id': _uuid(),
-                           'address': '127.0.0.1',
-                           'protocol_port': 80,
-                           'weight': 1,
-                           'admin_state_up': True,
-                           'tenant_id': _uuid()}}
-        return_value = copy.copy(data['member'])
-        return_value.update({'status': "ACTIVE", 'id': member_id})
-
-        instance = self.plugin.return_value
-        instance.create_member.return_value = return_value
-        res = self.api.post(_get_path('lb/members', fmt=self.fmt),
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt)
-        instance.create_member.assert_called_with(mock.ANY,
-                                                  member=data)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('member', res)
-        self.assertEqual(return_value, res['member'])
-
-    def test_member_list(self):
-        member_id = _uuid()
-        return_value = [{'name': 'member1',
-                         'admin_state_up': True,
-                         'tenant_id': _uuid(),
-                         'id': member_id}]
-
-        instance = self.plugin.return_value
-        instance.get_members.return_value = return_value
-
-        res = self.api.get(_get_path('lb/members', fmt=self.fmt))
-
-        instance.get_members.assert_called_with(mock.ANY, fields=mock.ANY,
-                                                filters=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-
-    def test_member_update(self):
-        member_id = _uuid()
-        update_data = {'member': {'admin_state_up': False}}
-        return_value = {'admin_state_up': False,
-                        'tenant_id': _uuid(),
-                        'status': "ACTIVE",
-                        'id': member_id}
-
-        instance = self.plugin.return_value
-        instance.update_member.return_value = return_value
-
-        res = self.api.put(_get_path('lb/members', id=member_id,
-                                     fmt=self.fmt),
-                           self.serialize(update_data))
-
-        instance.update_member.assert_called_with(mock.ANY, member_id,
-                                                  member=update_data)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('member', res)
-        self.assertEqual(return_value, res['member'])
-
-    def test_member_get(self):
-        member_id = _uuid()
-        return_value = {'admin_state_up': False,
-                        'tenant_id': _uuid(),
-                        'status': "ACTIVE",
-                        'id': member_id}
-
-        instance = self.plugin.return_value
-        instance.get_member.return_value = return_value
-
-        res = self.api.get(_get_path('lb/members', id=member_id,
-                                     fmt=self.fmt))
-
-        instance.get_member.assert_called_with(mock.ANY, member_id,
-                                               fields=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('member', res)
-        self.assertEqual(return_value, res['member'])
-
-    def test_member_delete(self):
-        self._test_entity_delete('member')
-
-    def test_health_monitor_create(self):
-        health_monitor_id = _uuid()
-        data = {'health_monitor': {'type': 'HTTP',
-                                   'delay': 2,
-                                   'timeout': 1,
-                                   'max_retries': 3,
-                                   'http_method': 'GET',
-                                   'url_path': '/path',
-                                   'expected_codes': '200-300',
-                                   'admin_state_up': True,
-                                   'tenant_id': _uuid()}}
-        return_value = copy.copy(data['health_monitor'])
-        return_value.update({'status': "ACTIVE", 'id': health_monitor_id})
-
-        instance = self.plugin.return_value
-        instance.create_health_monitor.return_value = return_value
-        res = self.api.post(_get_path('lb/health_monitors',
-                                      fmt=self.fmt),
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt)
-        instance.create_health_monitor.assert_called_with(mock.ANY,
-                                                          health_monitor=data)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('health_monitor', res)
-        self.assertEqual(return_value, res['health_monitor'])
-
-    def test_health_monitor_create_with_timeout_negative(self):
-        data = {'health_monitor': {'type': 'HTTP',
-                                   'delay': 2,
-                                   'timeout': -1,
-                                   'max_retries': 3,
-                                   'http_method': 'GET',
-                                   'url_path': '/path',
-                                   'expected_codes': '200-300',
-                                   'admin_state_up': True,
-                                   'tenant_id': _uuid()}}
-        res = self.api.post(_get_path('lb/health_monitors',
-                                      fmt=self.fmt),
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt,
-                            expect_errors=True)
-        self.assertEqual(400, res.status_int)
-
-    def test_health_monitor_list(self):
-        health_monitor_id = _uuid()
-        return_value = [{'type': 'HTTP',
-                         'admin_state_up': True,
-                         'tenant_id': _uuid(),
-                         'id': health_monitor_id}]
-
-        instance = self.plugin.return_value
-        instance.get_health_monitors.return_value = return_value
-
-        res = self.api.get(_get_path('lb/health_monitors', fmt=self.fmt))
-
-        instance.get_health_monitors.assert_called_with(
-            mock.ANY, fields=mock.ANY, filters=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-
-    def test_health_monitor_update(self):
-        health_monitor_id = _uuid()
-        update_data = {'health_monitor': {'admin_state_up': False}}
-        return_value = {'type': 'HTTP',
-                        'admin_state_up': False,
-                        'tenant_id': _uuid(),
-                        'status': "ACTIVE",
-                        'id': health_monitor_id}
-
-        instance = self.plugin.return_value
-        instance.update_health_monitor.return_value = return_value
-
-        res = self.api.put(_get_path('lb/health_monitors',
-                                     id=health_monitor_id,
-                                     fmt=self.fmt),
-                           self.serialize(update_data))
-
-        instance.update_health_monitor.assert_called_with(
-            mock.ANY, health_monitor_id, health_monitor=update_data)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('health_monitor', res)
-        self.assertEqual(return_value, res['health_monitor'])
-
-    def test_health_monitor_get(self):
-        health_monitor_id = _uuid()
-        return_value = {'type': 'HTTP',
-                        'admin_state_up': False,
-                        'tenant_id': _uuid(),
-                        'status': "ACTIVE",
-                        'id': health_monitor_id}
-
-        instance = self.plugin.return_value
-        instance.get_health_monitor.return_value = return_value
-
-        res = self.api.get(_get_path('lb/health_monitors',
-                                     id=health_monitor_id,
-                                     fmt=self.fmt))
-
-        instance.get_health_monitor.assert_called_with(
-            mock.ANY, health_monitor_id, fields=mock.ANY)
-        self.assertEqual(exc.HTTPOk.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('health_monitor', res)
-        self.assertEqual(return_value, res['health_monitor'])
-
-    def test_health_monitor_delete(self):
-        self._test_entity_delete('health_monitor')
-
-    def test_create_pool_health_monitor(self):
-        health_monitor_id = _uuid()
-        data = {'health_monitor': {'id': health_monitor_id,
-                                   'tenant_id': _uuid()}}
-
-        return_value = copy.copy(data['health_monitor'])
-        instance = self.plugin.return_value
-        instance.create_pool_health_monitor.return_value = return_value
-        res = self.api.post('/lb/pools/id1/health_monitors',
-                            self.serialize(data),
-                            content_type='application/%s' % self.fmt)
-        instance.create_pool_health_monitor.assert_called_with(
-            mock.ANY, pool_id='id1', health_monitor=data)
-        self.assertEqual(exc.HTTPCreated.code, res.status_int)
-        res = self.deserialize(res)
-        self.assertIn('health_monitor', res)
-        self.assertEqual(return_value, res['health_monitor'])
-
-    def test_delete_pool_health_monitor(self):
-        health_monitor_id = _uuid()
-
-        res = self.api.delete('/lb/pools/id1/health_monitors/%s' %
-                              health_monitor_id)
-
-        instance = self.plugin.return_value
-        instance.delete_pool_health_monitor.assert_called_with(
-            mock.ANY, health_monitor_id, pool_id='id1')
-        self.assertEqual(exc.HTTPNoContent.code, res.status_int)
-
-
-class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
-    fmt = 'json'
-
-    def setUp(self):
-        super(LoadBalancerExtensionV2TestCase, self).setUp()
+        super(TestLoadBalancerExtensionV2TestCase, self).setUp()
         resource_map = loadbalancerv2.RESOURCE_ATTRIBUTE_MAP.copy()
         for k in sharedpools.EXTENDED_ATTRIBUTES_2_0.keys():
             resource_map[k].update(sharedpools.EXTENDED_ATTRIBUTES_2_0[k])
+        for k in hm_down.EXTENDED_ATTRIBUTES_2_0.keys():
+            resource_map[k].update(hm_down.EXTENDED_ATTRIBUTES_2_0[k])
+        for k in lb_network_vip.EXTENDED_ATTRIBUTES_2_0.keys():
+            resource_map[k].update(lb_network_vip.EXTENDED_ATTRIBUTES_2_0[k])
         self._setUpExtension(
             'neutron_lbaas.extensions.loadbalancerv2.LoadBalancerPluginBaseV2',
             constants.LOADBALANCERV2, resource_map,
@@ -502,9 +52,11 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
     def test_loadbalancer_create(self):
         lb_id = _uuid()
+        project_id = _uuid()
         data = {'loadbalancer': {'name': 'lb1',
                                  'description': 'descr_lb1',
-                                 'tenant_id': _uuid(),
+                                 'tenant_id': project_id,
+                                 'project_id': project_id,
                                  'vip_subnet_id': _uuid(),
                                  'admin_state_up': True,
                                  'vip_address': '127.0.0.1'}}
@@ -517,8 +69,43 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         res = self.api.post(_get_path('lbaas/loadbalancers', fmt=self.fmt),
                             self.serialize(data),
                             content_type='application/{0}'.format(self.fmt))
-        data['loadbalancer'].update({'provider': attr.ATTR_NOT_SPECIFIED,
-                                     'flavor_id': attr.ATTR_NOT_SPECIFIED})
+        data['loadbalancer'].update({
+            'provider': n_constants.ATTR_NOT_SPECIFIED,
+            'flavor_id': n_constants.ATTR_NOT_SPECIFIED,
+            'vip_network_id': n_constants.ATTR_NOT_SPECIFIED})
+        instance.create_loadbalancer.assert_called_with(mock.ANY,
+                                                        loadbalancer=data)
+
+        self.assertEqual(exc.HTTPCreated.code, res.status_int)
+        res = self.deserialize(res)
+        self.assertIn('loadbalancer', res)
+        self.assertEqual(return_value, res['loadbalancer'])
+
+    def test_loadbalancer_create_with_vip_network_id(self):
+        lb_id = _uuid()
+        project_id = _uuid()
+        vip_subnet_id = _uuid()
+        data = {'loadbalancer': {'name': 'lb1',
+                                 'description': 'descr_lb1',
+                                 'tenant_id': project_id,
+                                 'project_id': project_id,
+                                 'vip_network_id': _uuid(),
+                                 'admin_state_up': True,
+                                 'vip_address': '127.0.0.1'}}
+        return_value = copy.copy(data['loadbalancer'])
+        return_value.update({'id': lb_id, 'vip_subnet_id': vip_subnet_id})
+        del return_value['vip_network_id']
+
+        instance = self.plugin.return_value
+        instance.create_loadbalancer.return_value = return_value
+
+        res = self.api.post(_get_path('lbaas/loadbalancers', fmt=self.fmt),
+                            self.serialize(data),
+                            content_type='application/{0}'.format(self.fmt))
+        data['loadbalancer'].update({
+            'provider': n_constants.ATTR_NOT_SPECIFIED,
+            'flavor_id': n_constants.ATTR_NOT_SPECIFIED,
+            'vip_subnet_id': n_constants.ATTR_NOT_SPECIFIED})
         instance.create_loadbalancer.assert_called_with(mock.ANY,
                                                         loadbalancer=data)
 
@@ -528,9 +115,11 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         self.assertEqual(return_value, res['loadbalancer'])
 
     def test_loadbalancer_create_invalid_flavor(self):
+        project_id = _uuid()
         data = {'loadbalancer': {'name': 'lb1',
                                  'description': 'descr_lb1',
-                                 'tenant_id': _uuid(),
+                                 'tenant_id': project_id,
+                                 'project_id': project_id,
                                  'vip_subnet_id': _uuid(),
                                  'admin_state_up': True,
                                  'flavor_id': 123,
@@ -542,9 +131,11 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         self.assertEqual(400, res.status_int)
 
     def test_loadbalancer_create_valid_flavor(self):
+        project_id = _uuid()
         data = {'loadbalancer': {'name': 'lb1',
                                  'description': 'descr_lb1',
-                                 'tenant_id': _uuid(),
+                                 'tenant_id': project_id,
+                                 'project_id': project_id,
                                  'vip_subnet_id': _uuid(),
                                  'admin_state_up': True,
                                  'flavor_id': _uuid(),
@@ -559,7 +150,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         lb_id = _uuid()
         return_value = [{'name': 'lb1',
                          'admin_state_up': True,
-                         'tenant_id': _uuid(),
+                         'project_id': _uuid(),
                          'id': lb_id}]
 
         instance = self.plugin.return_value
@@ -577,7 +168,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         update_data = {'loadbalancer': {'admin_state_up': False}}
         return_value = {'name': 'lb1',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': lb_id}
 
         instance = self.plugin.return_value
@@ -599,7 +190,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         lb_id = _uuid()
         return_value = {'name': 'lb1',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': lb_id}
 
         instance = self.plugin.return_value
@@ -621,7 +212,9 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
     def test_listener_create(self):
         listener_id = _uuid()
-        data = {'listener': {'tenant_id': _uuid(),
+        project_id = _uuid()
+        data = {'listener': {'tenant_id': project_id,
+                             'project_id': project_id,
                              'name': 'listen-name-1',
                              'description': 'listen-1-desc',
                              'protocol': 'HTTP',
@@ -652,10 +245,12 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
     def test_listener_create_with_tls(self):
         listener_id = _uuid()
+        project_id = _uuid()
         tls_ref = 'http://example.ref/uuid'
         sni_refs = ['http://example.ref/uuid',
                     'http://example.ref/uuid1']
-        data = {'listener': {'tenant_id': _uuid(),
+        data = {'listener': {'tenant_id': project_id,
+                             'project_id': project_id,
                              'name': 'listen-name-1',
                              'description': 'listen-1-desc',
                              'protocol': 'HTTP',
@@ -685,7 +280,9 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         self.assertEqual(res['listener'], return_value)
 
     def test_listener_create_with_connection_limit_less_than_min_value(self):
-        data = {'listener': {'tenant_id': _uuid(),
+        project_id = _uuid()
+        data = {'listener': {'tenant_id': project_id,
+                             'project_id': project_id,
                              'name': 'listen-name-1',
                              'description': 'listen-1-desc',
                              'protocol': 'HTTP',
@@ -705,7 +302,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
     def test_listener_list(self):
         listener_id = _uuid()
         return_value = [{'admin_state_up': True,
-                         'tenant_id': _uuid(),
+                         'project_id': _uuid(),
                          'id': listener_id}]
 
         instance = self.plugin.return_value
@@ -723,7 +320,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         update_data = {'listener': {'admin_state_up': False}}
         return_value = {'name': 'listener1',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': listener_id}
 
         instance = self.plugin.return_value
@@ -749,7 +346,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         update_data = {'listener': {'admin_state_up': False}}
         return_value = {'name': 'listener1',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': listener_id,
                         'default_tls_container_ref': tls_ref,
                         'sni_container_refs': sni_refs}
@@ -783,7 +380,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         listener_id = _uuid()
         return_value = {'name': 'listener1',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': listener_id}
 
         instance = self.plugin.return_value
@@ -805,6 +402,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
     def test_pool_create(self):
         pool_id = _uuid()
+        project_id = _uuid()
         data = {'pool': {'name': 'pool1',
                          'description': 'descr_pool1',
                          'protocol': 'HTTP',
@@ -812,7 +410,8 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                          'admin_state_up': True,
                          'loadbalancer_id': _uuid(),
                          'listener_id': None,
-                         'tenant_id': _uuid(),
+                         'tenant_id': project_id,
+                         'project_id': project_id,
                          'session_persistence': {}}}
         return_value = copy.copy(data['pool'])
         return_value.update({'id': pool_id})
@@ -833,7 +432,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         pool_id = _uuid()
         return_value = [{'name': 'pool1',
                          'admin_state_up': True,
-                         'tenant_id': _uuid(),
+                         'project_id': _uuid(),
                          'id': pool_id}]
 
         instance = self.plugin.return_value
@@ -850,7 +449,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         update_data = {'pool': {'admin_state_up': False}}
         return_value = {'name': 'pool1',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': pool_id}
 
         instance = self.plugin.return_value
@@ -871,7 +470,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         pool_id = _uuid()
         return_value = {'name': 'pool1',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': pool_id}
 
         instance = self.plugin.return_value
@@ -893,12 +492,14 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
     def test_pool_member_create(self):
         subnet_id = _uuid()
         member_id = _uuid()
+        project_id = _uuid()
         data = {'member': {'address': '10.0.0.1',
                            'protocol_port': 80,
                            'weight': 1,
                            'subnet_id': subnet_id,
                            'admin_state_up': True,
-                           'tenant_id': _uuid(),
+                           'tenant_id': project_id,
+                           'project_id': project_id,
                            'name': 'member1'}}
         return_value = copy.copy(data['member'])
         return_value.update({'id': member_id})
@@ -922,7 +523,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         member_id = _uuid()
         return_value = [{'name': 'member1',
                          'admin_state_up': True,
-                         'tenant_id': _uuid(),
+                         'project_id': _uuid(),
                          'id': member_id,
                          'name': 'member1'}]
 
@@ -942,7 +543,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         member_id = _uuid()
         update_data = {'member': {'admin_state_up': False}}
         return_value = {'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': member_id,
                         'name': 'member1'}
 
@@ -965,7 +566,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
     def test_pool_member_get(self):
         member_id = _uuid()
         return_value = {'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': member_id,
                         'name': 'member1'}
 
@@ -997,15 +598,18 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
 
     def test_health_monitor_create(self):
         health_monitor_id = _uuid()
+        project_id = _uuid()
         data = {'healthmonitor': {'type': 'HTTP',
                                   'delay': 2,
                                   'timeout': 1,
                                   'max_retries': 3,
+                                  'max_retries_down': 3,
                                   'http_method': 'GET',
                                   'url_path': '/path',
                                   'expected_codes': '200-300',
                                   'admin_state_up': True,
-                                  'tenant_id': _uuid(),
+                                  'tenant_id': project_id,
+                                  'project_id': project_id,
                                   'pool_id': _uuid(),
                                   'name': 'monitor1'}}
         return_value = copy.copy(data['healthmonitor'])
@@ -1026,6 +630,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         self.assertEqual(return_value, res['healthmonitor'])
 
     def test_health_monitor_create_with_timeout_negative(self):
+        project_id = _uuid()
         data = {'healthmonitor': {'type': 'HTTP',
                                   'delay': 2,
                                   'timeout': -1,
@@ -1034,7 +639,8 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
                                   'url_path': '/path',
                                   'expected_codes': '200-300',
                                   'admin_state_up': True,
-                                  'tenant_id': _uuid(),
+                                  'tenant_id': project_id,
+                                  'project_id': project_id,
                                   'pool_id': _uuid(),
                                   'name': 'monitor1'}}
         res = self.api.post(_get_path('lbaas/healthmonitors',
@@ -1048,7 +654,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         health_monitor_id = _uuid()
         return_value = [{'type': 'HTTP',
                          'admin_state_up': True,
-                         'tenant_id': _uuid(),
+                         'project_id': _uuid(),
                          'id': health_monitor_id,
                          'name': 'monitor1'}]
 
@@ -1066,7 +672,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         update_data = {'healthmonitor': {'admin_state_up': False}}
         return_value = {'type': 'HTTP',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': health_monitor_id,
                         'name': 'monitor1'}
 
@@ -1089,7 +695,7 @@ class LoadBalancerExtensionV2TestCase(base.ExtensionTestCase):
         health_monitor_id = _uuid()
         return_value = {'type': 'HTTP',
                         'admin_state_up': False,
-                        'tenant_id': _uuid(),
+                        'project_id': _uuid(),
                         'id': health_monitor_id,
                         'name': 'monitor1'}
 
